@@ -74,11 +74,35 @@ def schedule(process_id, schedule_id, data_id=None):
             logger.warning("schedule not exist, give up, sched_id: {}".format(schedule_id))
             return
 
+        # check whether the node is in a state waiting for scheduling
+        service_act = sched_service.service_act
+        act_id = sched_service.activity_id
+        version = sched_service.version
+
+        if not Status.objects.filter(id=act_id, version=version, state=states.RUNNING).exists():
+            # forced failed
+            logger.warning(
+                "schedule service failed, schedule({} - {}) node state is not running or version do not match.".format(
+                    act_id, version
+                )
+            )
+            sched_service.destroy()
+            return
+
         # try update lock schedule
         is_updated = ScheduleService.objects.filter(id=schedule_id, is_scheduling=False).update(is_scheduling=True)
 
         # lock failed, other worker may locking
         if is_updated == 0:
+            # only retry at multi calback enabled case
+            if not sched_service.multi_callback_enabled:
+                logger.warning(
+                    "invalid schedule request, schedule({} - {}) node state is not multi callback enabled type.".format(
+                        act_id, version
+                    )
+                )
+                return
+
             # retry lock after seconds
             logger.warning("schedule service lock-{} failed, retry after seconds".format(schedule_id))
             valve.send(
@@ -93,18 +117,6 @@ def schedule(process_id, schedule_id, data_id=None):
             return
 
         with auto_release_schedule_lock(schedule_id):
-            service_act = sched_service.service_act
-            act_id = sched_service.activity_id
-            version = sched_service.version
-
-            if not Status.objects.filter(id=act_id, version=version).exists():
-                # forced failed
-                logger.warning(
-                    "schedule service failed, schedule({} - {}) had been forced exit.".format(act_id, version)
-                )
-                sched_service.destroy()
-                return
-
             # get data
             parent_data = get_schedule_parent_data(sched_service.id)
             if parent_data is None:
