@@ -234,3 +234,19 @@ class HooksMixin:
         :param data: 回调数据
         :type data: str
         """
+
+    def pre_retry_subprocess(self, node_id: str):
+        """
+        子流程重试前执行的钩子
+
+        :param node_id: 子流程节点 ID
+        :type node_id: str
+        """
+
+    def post_retry_subprocess(self, node_id: str):
+        """
+        子流程重试后执行的钩子
+
+        :param node_id: 子流程节点 ID
+        :type node_id: str
+        """
